import pandas as pd 
import numpy as np 
from sklearn.model_selection import train_test_split
from sklearn.preprocessing import StandardScaler
from sklearn.linear_model import LogisticRegression 
from sklearn.tree import DecisionTreeClassifier
from sklearn.neural_network import MLPClassifier
from sklearn.svm import LinearSVC
from sklearn.neighbors import KNeighborsClassifier
from sklearn.ensemble import RandomForestClassifier
from sklearn.naive_bayes import GaussianNB
from sklearn.model_selection import cross_val_score

np.random.seed(2018)

labels = {
    1: "1starLA",
    2: "1starLB",
    3: "1starH2",
    4: "1starBL",
    # 5: "44"
}

clfs = {
    "LogisticRegression": LogisticRegression(class_weight='balanced', solver='lbfgs', max_iter=200, multi_class='multinomial', ),
    "DecisionTreeClassifier": DecisionTreeClassifier(class_weight='balanced'),
    "MLPClassifier": MLPClassifier(max_iter=1000, solver='lbfgs', early_stopping=True),
    "LinearSVC": LinearSVC(class_weight='balanced'),
    "KNeighborsClassifier": KNeighborsClassifier(),
    "RandomForestClassifier": RandomForestClassifier(class_weight='balanced'),
    "GaussianNB": GaussianNB()
}
main_df = pd.read_excel('../data/combined.xlsx', "Exp", index_col=None, header=0)

all_cols = []
for clf in clfs:
    all_cols.append("{}".format(clf))

#res_df = pd.DataFrame(
#     columns=all_cols, 
#     index=list(labels.values())
#    )

# for label in labels:
#     lines = [line.rstrip('\n') for line in open('../data/miRNA_list/{}.txt'.format(labels[label]))]
#     genes = ['Patient_Full_BarCode'] + lines + ['Label']
#     curr_df = main_df[genes]
#     for clf in clfs:
#         X = curr_df.values[:, 1:-1]
#         y = curr_df.values[:, -1]
#         y = (y == label).astype(int)
#         print(clf)
#         clf1 = clfs[clf]
#         scores = cross_val_score(clf1, X, y, cv=5)
#         clf1.fit(X, y)
#         print("Accuracy: %0.2f\n" % (scores.mean()))
#         res_df.ix[labels[label], "{}".format(clf)] = scores.mean()

# lines = [line.rstrip('\n') for line in open('../data/miRNA_list/44.txt')]
# genes = ['Patient_Full_BarCode'] + lines + ['Label']
# curr_df = main_df[genes]
# for clf in clfs:
#     X = curr_df.values[:, 1:-1]
#     y = curr_df.values[:, -1]
#     y = (y == 5).astype(int)
#     print(clf)
#     clf1 = clfs[clf]
#     scores = cross_val_score(clf1, X, y, cv=5)
#     clf1.fit(X, y)
#     print("Accuracy: %0.2f\n" % (scores.mean()))
#     res_df.ix["44", "{}".format(clf)] = scores.mean()


gene_df = pd.read_excel("../data/mirnas_other.xlsx", None, header=None, index_col=None)
sheets = list(gene_df.keys())
print(sheets)
res_df = pd.DataFrame(
    # columns=all_cols, 
    # index=sheets,
    )
for sheet in sheets:
    gene_df = pd.read_excel("../data/mirnas_other.xlsx", sheet, header=None, index_col=None)
    print(gene_df.head())
    lines = gene_df[0].values  
    lines = [w.replace('has-', 'hsa-') for w in lines]
    lines = ["hsa-" + line if not line.startswith("hsa-") else line for line in lines]
    
    lines = list(np.intersect1d(lines, main_df.columns.values))
    print(lines)
    if len(lines) == 0:
        continue 
    print(len(lines))
    genes = ['Patient_Full_BarCode'] + lines + ['Label']
    curr_df = main_df[genes]
    for clf in clfs:
        X = curr_df.values[:, 1:-1]
        y = curr_df.values[:, -1]
        y = (y == 5).astype(int)
        print(clf)
        clf1 = clfs[clf]
        scores = cross_val_score(clf1, X, y, cv=5)
        clf1.fit(X, y)
        print("Accuracy: %0.2f\n" % (scores.mean()))
        res_df.ix["{}_{}".format(len(lines), sheet), "{}".format(clf)] = scores.mean()

res_df.to_csv("../classify_1star_new.csv", float_format='% 4.4f')
